# 说明
## 依赖
* docker >= 17.09
* docker-compose

包含了everst 和 zookeeper 的docker-compose配置文件，其中 everst 只支持 metadb 和 everest 的启动，暂不支持 engine

## hsenv 配置说明

```
#hengshi-sense 镜像的 tag 版本
HS_IMAGE_TAG=develop

#可选, volumn的根路径,默认为docker-compose.yaml目录下
HSHOME=.

#可选, hengshi web service port
HS_HENGSHI_EXPOSE_PORT=8080

#可选, hengshi 数据网关端口
DATA_GATEWAY_PUBLIC_EXPOSE_PORT=8079

#可选, 容器对外暴露的 metadb 端口, 默认54320
HS_PG_EXPOSE_PORT=54320

# 可选, engine对外暴露的 端口, 默认15432
HS_ENGINE_EXPOSE_PORT=15432

# remote debug port
HS_JDWP_EXPOSE_PORT=5005
```

## 单机部属
1. hsenv 文件中 **重点是 HS_IMAGE_TAG 变量, 将值设置为当前 hengshi-sense 镜像的 tag**
1. 修改配置 volumes, 如果端口被占用，还需修改 ports

1. 初始化
```shell
cd single #这一步一定要进入single目录, 保证后面 hsenv 变量会生效
cp ../hsenv hsenv #然后修改hsenv中的变量, HS_IMAGE_TAG 为必须修改的
docker-compose --env-file hsenv run --rm metadb init metadb
docker-compose --env-file hsenv run --rm engine init engine
```

1. 启动服务
```shell
cd single
docker-compose --env-file hsenv up -d
```

1. 暂停服务
```shell
cd single
docker-compose --env-file hsenv stop
```

1. 停止服务并删掉容器
```shell
cd single
docker-compose --env-file hsenv down
```

## 升级版本

1. 获取和更新镜像, 参考 [获取镜像](docker.md#获取镜像)

1. 暂停服务
```shell
cd single
docker-compose --env-file hsenv stop
```

1. 更新衡石 tag
```shell
cd single
NEW_TAG=hengshi-sense-xxx #设置变量为新tag
sed -i -e "s/^HS_IMAGE_TAG=.*$/HS_IMAGE_TAG=${NEW_TAG}/" hsenv
```

1. 启动服务
```shell
cd single
docker-compose --env-file hsenv up -d
```

## 备份数据
备份/还原使用 [备份/还原数据](backup-restore.md) 中的备份/还原脚本, 区别是所有命令需要在当前名为 hengshi-sense 的容器中执行

注意: 在 docker 环境中, 只使用本地备份方式, 且备份到 hsenv 中配置的 HSHOME 下的 backup 目录下, 默认为 single/hsdata/backup

### 举例
* 备份 metadb
```shell
cd single
docker exec -it hengshi-sense mkdir /opt/hsdata/backup
docker exec -it hengshi-sense /opt/hengshi/bin/dbbackup.sh -m metadb -l /opt/hsdata/backup
```

* 还原 metadb
```shell
cd single
docker-compose --env-file hsenv stop
source hsenv
sudo mv ${HSHOME}/hsdata/pg_data ${HSHOME}/hsdata/pg_data.old
docker-compose --env-file hsenv run --rm metadb init metadb
docker-compose --env-file hsenv start metadb
docker exec -it hengshi-metadb /opt/hengshi/bin/dbrestore.sh -m metadb -l /opt/hsdata/backup -t metadb_backup.xx-xx-xx_xx:xx:xx.tar.gz
docker-compose --env-file hsenv stop metadb
docker-compose --env-file hsenv start
```
